{% load staticfiles %}

<!DOCTYPE html>
<html lang="en">
	<head>
	    <meta charset="utf-8">
	    <meta http-equiv="X-UA-Compatible" content="IE=edge">
	    <meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css" integrity="sha384-BVYiiSIFeK1dGmJRAkycuHAHRg32OmUcww7on3RYdg4Va+PmSTsz/K68vbdEjh4u" crossorigin="anonymous">
		<link rel="stylesheet" href="{% static "css/bundle.css" %}">
		<link href="https://fonts.googleapis.com/css?family=Arimo&subset=cyrillic,latin-ext" 
		rel="stylesheet">
		<title>Phonotactic Probability Calculator for Serbian Language</title>
	</head>
	<body>
		<div class="container">
			<div class="row text-center alert alert-custom">
				<div class="col-md-8 col-md-offset-2 header">
					<a href="/">
						<h2><b>Phonotactic Probability Calculator</b></h2>
						<h3><b>for Serbian Language</b></h3>
					</a>
				</div>
			</div>
			<div class="content">
				{% block content %}	
				{% endblock content %}
			</div>
		</div>
	</body>
</html>